class Data:
    class Type:
        PORTFOLIO = 'portfolio'
        CASHFUNDS = 'cashFunds'